==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "S'està carregant la previsualització...",
    "Admin" : "Administrador",
    "Saved" : "Desat",
    "a safe home for all your data" : "Un lloc segur per a les vostres dades",
    "Name cannot be empty" : "El nom no pot estar buit",
    "The given name is too long" : "El nom proporcionat és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given web address is not a valid URL" : "L'adreça web proporcionada no és un URL vàlid",
    "The given legal notice address is too long" : "L'adreça d'avís legal és massa llarga",
    "The given legal notice address is not a valid URL" : "L'adreça proporcionada per notificacions no és una URL vàlida",
    "The given privacy policy address is too long" : "L'adreça de política de privadesa és massa llarga",
    "The given privacy policy address is not a valid URL" : "L'adreça proporcionada per a la política de privacitat no és una URL vàlida",
    "The given slogan is too long" : "L'eslògan proporcionat és massa llarg",
    "The given color is invalid" : "El color proporcionat no és vàlid",
    "The file was uploaded" : "S'ha pujat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer carregat supera la directiva upload_max_filesize a php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
    "The file was only partially uploaded" : "El fitxer només es ha estat carregat parcialment",
    "No file was uploaded" : "No s'ha pujat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer en el disc",
    "A PHP extension stopped the file upload" : "Una extensió de PHP ha aturat la càrrega del fitxer",
    "No file uploaded" : "No s'ha carregat cap fitxer",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja esteu fent servir un tema propi. La configuració de l'aplicació s'hauria d'haver modificat.",
    "Theming" : "Aparença",
    "Appearance and accessibility" : "Aspecte i accessibilitat",
    "Dark theme" : "Tema fosc",
    "Enable dark theme" : "Habilita el tema fosc",
    "Dyslexia font" : "Tipus de lletra per a la dislèxia",
    "Enable dyslexia font" : "Habilita el tipus de lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és un tipus de lletra gratuït dissenyat per a mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "High contrast mode" : "Mode de contrast alt",
    "Enable high contrast mode" : "Habilita el mode de contrast alt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mode de contrast alt per a facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Adjust the Nextcloud theme" : "Ajusteu el tema del Nextcloud",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accés universal és molt important per a nosaltres. Seguim els estàndards web i comprovem que tot es pugui utilitzar també sense el ratolí i amb programes d'assistència, com ara els lectors de pantalla. Volem complir les {guidelines}Pautes d'accessibilitat del contingut web{linkend} 2.1 a nivell AA i amb el tema de contrast alt fins i tot a nivell AAA.",
    "Pick from Files" : "Trieu dels fitxers",
    "Plain background" : "Fons senzill",
    "Insert from {productName}" : "Insereix des de {productName}",
    "Open documentation" : "Obre la documentació",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "L'aparença permet personalitzar fàcilment l'aspecte de la vostra web i dels clients. Això serà visible per a tots els usuaris.",
    "Name" : "Nom",
    "Reset to default" : "Restableix als valors predeterminats",
    "Web link" : "Enllaç web",
    "https://…" : "https://...",
    "Slogan" : "Eslògan",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Puja un logotip nou",
    "Login image" : "Imatge d'inici de sessió",
    "Upload new login background" : "Carrega un nou fons d'inici de sessió",
    "Remove background image" : "Suprimeix la imatge de fons",
    "Advanced options" : "Paràmetres avançats",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logotip de capçalera",
    "Upload new header logo" : "Puja un logotip de capçalera nou",
    "Favicon" : "Icona de web",
    "Upload new favicon" : "Carrega un nou favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió PHP de l'ImageMagick compatible amb imatges SVG per generar automàticament una icona de web a partir del logotip pujat i del color."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nom proporcionat és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given web address is not a valid URL" : "L'adreça web proporcionada no és un URL vàlid",
    "The given legal notice address is too long" : "L'adreça d'avís legal és massa llarga",
    "The given legal notice address is not a valid URL" : "L'adreça proporcionada per notificacions no és una URL vàlida",
    "The given privacy policy address is too long" : "L'adreça de política de privadesa és massa llarga",
    "The given privacy policy address is not a valid URL" : "L'adreça proporcionada per a la política de privacitat no és una URL vàlida",
    "The given slogan is too long" : "L'eslògan proporcionat és massa llarg",
    "The given color is invalid" : "El color proporcionat no és vàlid",
    "Saved" : "Desat",
    "The file was uploaded" : "S'ha pujat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer carregat supera la directiva upload_max_filesize a php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
    "The file was only partially uploaded" : "El fitxer només es ha estat carregat parcialment",
    "No file was uploaded" : "No s'ha pujat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer en el disc",
    "A PHP extension stopped the file upload" : "Una extensió de PHP ha aturat la càrrega del fitxer",
    "No file uploaded" : "No s'ha carregat cap fitxer",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja esteu fent servir un tema propi. La configuració de l'aplicació s'hauria d'haver modificat.",
    "Theming" : "Aparença",
    "Appearance and accessibility" : "Aspecte i accessibilitat",
    "Dark theme" : "Tema fosc",
    "Enable dark theme" : "Habilita el tema fosc",
    "Dyslexia font" : "Tipus de lletra per a la dislèxia",
    "Enable dyslexia font" : "Habilita el tipus de lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és un tipus de lletra gratuït dissenyat per a mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "High contrast mode" : "Mode de contrast alt",
    "Enable high contrast mode" : "Habilita el mode de contrast alt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mode de contrast alt per a facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Adjust the Nextcloud theme" : "Ajusteu el tema del Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "L'aparença permet personalitzar fàcilment l'aspecte de la vostra web i dels clients. Això serà visible per a tots els usuaris.",
    "Advanced options" : "Paràmetres avançats",
    "Name" : "Nom",
    "Web link" : "Enllaç web",
    "a safe home for all your data" : "Un lloc segur per a les vostres dades",
    "Slogan" : "Eslògan",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Puja un logotip nou",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logotip de capçalera",
    "Upload new header logo" : "Puja un logotip de capçalera nou",
    "Favicon" : "Icona de web",
    "Upload new favicon" : "Carrega un nou favicon",
    "User settings" : "Paràmetres de l'usuari",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accés universal és molt important per a nosaltres. Seguim els estàndards web i comprovem que tot es pugui utilitzar també sense el ratolí i amb programes d'assistència, com ara els lectors de pantalla. Volem complir les {guidelines}Pautes d'accessibilitat del contingut web{linkend} 2.1 a nivell AA i amb el tema de contrast alt fins i tot a nivell AAA.",
    "Pick from Files" : "Trieu dels fitxers",
    "Custom color" : "Color personalitzat",
    "Plain background" : "Fons senzill",
    "Insert from {productName}" : "Insereix des de {productName}",
    "Reset to default" : "Restableix als valors predeterminats",
    "Upload" : "Pujada",
    "Remove background image" : "Suprimeix la imatge de fons",
    "Loading preview…" : "S'està carregant la previsualització...",
    "Admin" : "Administrador",
    "Name cannot be empty" : "El nom no pot estar buit",
    "Open documentation" : "Obre la documentació",
    "https://…" : "https://...",
    "Login image" : "Imatge d'inici de sessió",
    "Upload new login background" : "Carrega un nou fons d'inici de sessió",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió PHP de l'ImageMagick compatible amb imatges SVG per generar automàticament una icona de web a partir del logotip pujat i del color."
},
"nplurals=2; plural=(n != 1);");
